ConfigBuilder

Struct ConfigBuilder 

pub struct ConfigBuilder { /* private fields */ }
Helper for building and validating a TUF client Config.

Implementations

Source

impl ConfigBuilder

pub fn finish(self) -> Result<Config>

Validate this builder return a Config if validation succeeds.

pub fn max_root_length(self, max: Option<usize>) -> Self

Set the optional maximum download length for root metadata.

pub fn max_timestamp_length(self, max: Option<usize>) -> Self

Set the optional maximum download length for timestamp metadata.

pub fn max_snapshot_length(self, max: Option<usize>) -> Self

Set the optional maximum download length for snapshot metadata.

pub fn max_targets_length(self, max: Option<usize>) -> Self

Set the optional maximum download length for targets metadata.

pub fn max_delegation_depth(self, max: u32) -> Self

Set the maximum number of steps used when walking the delegation graph.