Parts

Struct Parts 

#[non_exhaustive]
pub struct Parts<D, L, R>{ pub config: Config, pub database: Database<D>, pub local: L, pub remote: R, }
Deconstructed parts of a Client.

This allows taking apart a Client in order to reclaim the Database, local, and remote repositories.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
config: Config

The client configuration.

database: Database<D>

The Tuf database, which is updated by the Client.

local: L

The local repository, which is used to initialize the database, and is updated by the Client.

remote: R

The remote repository, which is used by the client to update the database.