pub async fn calculate_hashes_from_reader<R>(
read: R,
hash_algs: &[HashAlgorithm],
) -> Result<(u64, HashMap<HashAlgorithm, HashValue>)>Expand description
Calculate the size and hash digest from a given AsyncRead.
pub async fn calculate_hashes_from_reader<R>(
read: R,
hash_algs: &[HashAlgorithm],
) -> Result<(u64, HashMap<HashAlgorithm, HashValue>)>Calculate the size and hash digest from a given AsyncRead.