pub fn calculate_hashes_from_slice(
buf: &[u8],
hash_algs: &[HashAlgorithm],
) -> Result<HashMap<HashAlgorithm, HashValue>>Expand description
Calculate the size and hash digest from a given AsyncRead.
pub fn calculate_hashes_from_slice(
buf: &[u8],
hash_algs: &[HashAlgorithm],
) -> Result<HashMap<HashAlgorithm, HashValue>>Calculate the size and hash digest from a given AsyncRead.