Error

Enum Error 

#[non_exhaustive]
pub enum Error {
Show 27 variants BadSignature(MetadataPath), Encoding(String), ExpiredMetadata { path: MetadataPath, expiration: DateTime<Utc>, now: DateTime<Utc>, }, IllegalArgument(String), Http { uri: String, err: Error, }, Hyper { uri: String, err: Error, }, BadHttpStatus { uri: String, code: StatusCode, }, Io(Error), IoPath { path: PathBuf, err: Error, }, Json(Error), NoSupportedHashAlgorithm, MetadataNotFound { path: MetadataPath, version: MetadataVersion, }, TargetNotFound(TargetPath), Opaque(String), UnknownKeyType(String), UnknownSignatureScheme(String), MetadataVersionMustBeGreaterThanZero(MetadataPath), MetadataVersionMustBeSmallerThanMaxU32(MetadataPath), MetadataThresholdMustBeGreaterThanZero(MetadataPath), MetadataRoleHasDuplicateKeyId { role: MetadataPath, key_id: KeyId, }, MetadataRoleDoesNotHaveEnoughKeyIds { role: MetadataPath, key_ids: usize, threshold: u32, }, MetadataMissingSignatures { role: MetadataPath, number_of_valid_signatures: u32, threshold: u32, }, AttemptedMetadataRollBack { role: MetadataPath, trusted_version: u32, new_version: u32, }, WrongMetadataVersion { parent_role: MetadataPath, child_role: MetadataPath, expected_version: u32, new_version: u32, }, MissingMetadataDescription { parent_role: MetadataPath, child_role: MetadataPath, }, UnauthorizedDelegation { parent_role: MetadataPath, child_role: MetadataPath, }, MissingPrivateKey { role: MetadataPath, },
}
Error type for all TUF related errors.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


BadSignature(MetadataPath)

The metadata had a bad signature.



Encoding(String)

There was a problem encoding or decoding.



ExpiredMetadata

Metadata was expired.

Fields

path: MetadataPath

The metadata that expired.

expiration: DateTime<Utc>

When the metadata expired.

now: DateTime<Utc>

The latest known time.



IllegalArgument(String)

An illegal argument was passed into a function.



Http

Generic error for HTTP connections.

Fields

uri: String

URI Resource that resulted in the error.

err: Error

The error.



Hyper

Errors that can occur parsing HTTP streams.

Fields

uri: String

URI Resource that resulted in the error.

err: Error

The error.



BadHttpStatus

Unexpected HTTP response status.

Fields

uri: String

URI Resource that resulted in the error.

code: StatusCode

HTTP status code.



Io(Error)

An IO error occurred.



IoPath

An IO error occurred for a path.

Fields

path: PathBuf

Path where the error occurred.

err: Error

The IO error.



Json(Error)

A json serialization error occurred.



NoSupportedHashAlgorithm

There were no available hash algorithms.



MetadataNotFound

The metadata was not found.

Fields

path: MetadataPath

The metadata path.

version: MetadataVersion

The metadata version.



TargetNotFound(TargetPath)

The target was not found.



Opaque(String)

Opaque error type, to be interpreted similar to HTTP 500. Something went wrong, and you may or may not be able to do anything about it.



UnknownKeyType(String)

There is no known or available key type.



UnknownSignatureScheme(String)

There is no known or available signature scheme.



MetadataVersionMustBeGreaterThanZero(MetadataPath)

The metadata’s version must be greater than 0.



MetadataVersionMustBeSmallerThanMaxU32(MetadataPath)

The metadata’s version must be less than u32::MAX.



MetadataThresholdMustBeGreaterThanZero(MetadataPath)

The metadata threshold must be greater than 0.



MetadataRoleHasDuplicateKeyId

The metadata role has a duplicate keyid.

Fields

role: MetadataPath

The metadata.

key_id: KeyId

The duplicated keyid.



MetadataRoleDoesNotHaveEnoughKeyIds

The metadata role does not have enough keyids.

Fields

role: MetadataPath

The metadata.

key_ids: usize

The number of keyids.

threshold: u32

The minimum threshold of keys.



MetadataMissingSignatures

The metadata was not signed with enough valid signatures.

Fields

role: MetadataPath

The signed metadata.

number_of_valid_signatures: u32

The number of signatures which are valid.

threshold: u32

The minimum number of valid signatures.



AttemptedMetadataRollBack

Attempted to update metadata with an older version.

Fields

role: MetadataPath

The metadata.

trusted_version: u32

The trusted metadata’s version.

new_version: u32

The new metadata’s version.



WrongMetadataVersion

The parent metadata expected the child metadata to be at one version, but was found to be at another version.

Fields

parent_role: MetadataPath

The parent metadata that contains the child metadata’s version.

child_role: MetadataPath

The child metadata that has an unexpected version.

expected_version: u32

The expected version of the child metadata.

new_version: u32

The actual version of the child metadata.



MissingMetadataDescription

The parent metadata does not contain a description of the child metadata.

Fields

parent_role: MetadataPath

The parent metadata that contains the child metadata’s description.

child_role: MetadataPath

The child metadata that should have been contained in the parent.



UnauthorizedDelegation

The parent metadata did not delegate to the child role.

Fields

parent_role: MetadataPath

The parent metadata that did not delegate to the child.

child_role: MetadataPath

That child metadata that was not delegated to by the parent.



MissingPrivateKey

The metadata must be signed with at least one private key.

Fields

role: MetadataPath

The metadata to be signed.