pub struct Delegations { /* private fields */ }Expand description
Wrapper to described a collections of delegations.
Implementations
Sourceimpl Delegations
impl Delegations
Sourcepub fn builder() -> DelegationsBuilder
pub fn builder() -> DelegationsBuilder
Return a DelegationsBuilder.
Sourcepub fn new(
keys: HashMap<KeyId, PublicKey>,
roles: Vec<Delegation>,
) -> Result<Self>
pub fn new( keys: HashMap<KeyId, PublicKey>, roles: Vec<Delegation>, ) -> Result<Self>
Create a new Delegations wrapper from the given set of trusted keys and roles.
Sourcepub fn keys(&self) -> &HashMap<KeyId, PublicKey>
pub fn keys(&self) -> &HashMap<KeyId, PublicKey>
An immutable reference to the keys used for this set of delegations.
Sourcepub fn roles(&self) -> &Vec<Delegation>
pub fn roles(&self) -> &Vec<Delegation>
An immutable reference to the delegated roles.