pub struct MetadataDescription<M: Metadata> { /* private fields */ }Expand description
Description of a piece of metadata, used in verification.
Implementations
Sourceimpl<M: Metadata> MetadataDescription<M>
impl<M: Metadata> MetadataDescription<M>
Sourcepub fn from_slice(
buf: &[u8],
version: u32,
hash_algs: &[HashAlgorithm],
) -> Result<Self>
pub fn from_slice( buf: &[u8], version: u32, hash_algs: &[HashAlgorithm], ) -> Result<Self>
Create a MetadataDescription from a slice. Size and hashes will be calculated.
Sourcepub fn new(
version: u32,
length: Option<usize>,
hashes: HashMap<HashAlgorithm, HashValue>,
) -> Result<Self>
pub fn new( version: u32, length: Option<usize>, hashes: HashMap<HashAlgorithm, HashValue>, ) -> Result<Self>
Create a new MetadataDescription.
Sourcepub fn hashes(&self) -> &HashMap<HashAlgorithm, HashValue>
pub fn hashes(&self) -> &HashMap<HashAlgorithm, HashValue>
An immutable reference to the hashes of the described metadata.