pub struct RawSignedMetadata<D, M> { /* private fields */ }Expand description
Unverified raw metadata with attached signatures and type information identifying the metadata’s type and serialization format.
Implementations
Sourceimpl<D, M> RawSignedMetadata<D, M>
impl<D, M> RawSignedMetadata<D, M>
Sourcepub fn new(bytes: Vec<u8>) -> Self
pub fn new(bytes: Vec<u8>) -> Self
Create a new RawSignedMetadata using the provided bytes.
Sourcepub fn parse_untrusted(&self) -> Result<SignedMetadata<D, M>>
pub fn parse_untrusted(&self) -> Result<SignedMetadata<D, M>>
Parse this metadata.
WARNING: This does not verify signatures, so it exposes users to potential parser exploits.