RawSignedMetadataSet

Struct RawSignedMetadataSet 

pub struct RawSignedMetadataSet<D> { /* private fields */ }
A collection of RawSignedMetadata that describes the metadata at one commit.

Implementations

Source

impl<D> RawSignedMetadataSet<D>

pub fn root(&self) -> Option<&RawSignedMetadata<D, RootMetadata>>

Returns a reference to the built root metadata, if any.

pub fn targets(&self) -> Option<&RawSignedMetadata<D, TargetsMetadata>>

Returns a reference to the built targets metadata, if any.

pub fn snapshot(&self) -> Option<&RawSignedMetadata<D, SnapshotMetadata>>

Returns a reference to the built snapshot metadata, if any.

pub fn timestamp(&self) -> Option<&RawSignedMetadata<D, TimestampMetadata>>

Returns a reference to the built timestamp metadata, if any.