pub struct RootMetadata { /* private fields */ }Expand description
Metadata for the root role.
Implementations
Sourceimpl RootMetadata
impl RootMetadata
Sourcepub fn new(
version: u32,
expires: DateTime<Utc>,
consistent_snapshot: bool,
keys: HashMap<KeyId, PublicKey>,
root: RoleDefinition<RootMetadata>,
snapshot: RoleDefinition<SnapshotMetadata>,
targets: RoleDefinition<TargetsMetadata>,
timestamp: RoleDefinition<TimestampMetadata>,
additional_fields: HashMap<String, Value>,
) -> Result<Self>
pub fn new( version: u32, expires: DateTime<Utc>, consistent_snapshot: bool, keys: HashMap<KeyId, PublicKey>, root: RoleDefinition<RootMetadata>, snapshot: RoleDefinition<SnapshotMetadata>, targets: RoleDefinition<TargetsMetadata>, timestamp: RoleDefinition<TimestampMetadata>, additional_fields: HashMap<String, Value>, ) -> Result<Self>
Create new RootMetadata.
Sourcepub fn consistent_snapshot(&self) -> bool
pub fn consistent_snapshot(&self) -> bool
Whether or not this repository is currently implementing that TUF consistent snapshot feature.
Sourcepub fn keys(&self) -> &HashMap<KeyId, PublicKey>
pub fn keys(&self) -> &HashMap<KeyId, PublicKey>
An immutable reference to the map of trusted keys.
Sourcepub fn root_keys(&self) -> impl Iterator<Item = &PublicKey>
pub fn root_keys(&self) -> impl Iterator<Item = &PublicKey>
An iterator over all the trusted root public keys.
Sourcepub fn targets_keys(&self) -> impl Iterator<Item = &PublicKey>
pub fn targets_keys(&self) -> impl Iterator<Item = &PublicKey>
An iterator over all the trusted targets public keys.
Sourcepub fn snapshot_keys(&self) -> impl Iterator<Item = &PublicKey>
pub fn snapshot_keys(&self) -> impl Iterator<Item = &PublicKey>
An iterator over all the trusted snapshot public keys.
Sourcepub fn timestamp_keys(&self) -> impl Iterator<Item = &PublicKey>
pub fn timestamp_keys(&self) -> impl Iterator<Item = &PublicKey>
An iterator over all the trusted timestamp public keys.
Sourcepub fn root(&self) -> &RoleDefinition<RootMetadata>
pub fn root(&self) -> &RoleDefinition<RootMetadata>
An immutable reference to the root role’s definition.
Sourcepub fn snapshot(&self) -> &RoleDefinition<SnapshotMetadata>
pub fn snapshot(&self) -> &RoleDefinition<SnapshotMetadata>
An immutable reference to the snapshot role’s definition.
Sourcepub fn targets(&self) -> &RoleDefinition<TargetsMetadata>
pub fn targets(&self) -> &RoleDefinition<TargetsMetadata>
An immutable reference to the targets role’s definition.
Sourcepub fn timestamp(&self) -> &RoleDefinition<TimestampMetadata>
pub fn timestamp(&self) -> &RoleDefinition<TimestampMetadata>
An immutable reference to the timestamp role’s definition.
Sourcepub fn additional_fields(&self) -> &HashMap<String, Value>
pub fn additional_fields(&self) -> &HashMap<String, Value>
An immutable reference to any additional fields on the metadata.