SignedMetadataBuilder

Struct SignedMetadataBuilder 

pub struct SignedMetadataBuilder<D, M>
where D: Pouf,
{ /* private fields */ }
Helper to construct SignedMetadata.

Implementations

Source

impl<D, M> SignedMetadataBuilder<D, M>
where D: Pouf, M: Metadata,

pub fn from_metadata(metadata: &M) -> Result<Self>

Create a new SignedMetadataBuilder from a given Metadata.

pub fn from_raw_metadata(metadata: D::RawData) -> Result<Self>

Create a new SignedMetadataBuilder from manually serialized metadata to be signed. Returns an error if metadata cannot be parsed into M.

pub fn sign(self, private_key: &dyn PrivateKey) -> Result<Self>

Sign the metadata using the given private_key, replacing any existing signatures with the same KeyId.

WARNING: You should never have multiple TUF private keys on the same machine, so if you’re using this to append several signatures at once, you are doing something wrong. The preferred method is to generate your copy of the metadata locally and use SignedMetadata::merge_signatures to perform the “append” operations.

pub fn build(self) -> SignedMetadata<D, M>

Construct a new SignedMetadata using the included signatures, sorting the signatures by KeyId.