pub struct SnapshotMetadata { /* private fields */ }Expand description
Metadata for the snapshot role.
Implementations
Sourceimpl SnapshotMetadata
impl SnapshotMetadata
Sourcepub fn new(
version: u32,
expires: DateTime<Utc>,
meta: HashMap<MetadataPath, MetadataDescription<TargetsMetadata>>,
additional_fields: HashMap<String, Value>,
) -> Result<Self>
pub fn new( version: u32, expires: DateTime<Utc>, meta: HashMap<MetadataPath, MetadataDescription<TargetsMetadata>>, additional_fields: HashMap<String, Value>, ) -> Result<Self>
Create new SnapshotMetadata.
Sourcepub fn meta(
&self,
) -> &HashMap<MetadataPath, MetadataDescription<TargetsMetadata>>
pub fn meta( &self, ) -> &HashMap<MetadataPath, MetadataDescription<TargetsMetadata>>
An immutable reference to the metadata paths and descriptions.
Sourcepub fn additional_fields(&self) -> &HashMap<String, Value>
pub fn additional_fields(&self) -> &HashMap<String, Value>
An immutable reference to any additional fields on the metadata.