SnapshotMetadataBuilder

Struct SnapshotMetadataBuilder 

pub struct SnapshotMetadataBuilder { /* private fields */ }
Helper to construct SnapshotMetadata.

Implementations

Source

impl SnapshotMetadataBuilder

pub fn new() -> Self

Create a new SnapshotMetadataBuilder. It defaults to:

  • version: 1
  • expires: 7 days from the current time.
pub fn from_targets<D>( targets: &SignedMetadata<D, TargetsMetadata>, hash_algs: &[HashAlgorithm], ) -> Result<Self>
where D: Pouf,

Create a new SnapshotMetadataBuilder from a given snapshot. It defaults to:

  • version: 1
  • expires: 7 day from the current time.
pub fn version(self, version: u32) -> Self

Set the version number for this metadata.

pub fn expires(self, expires: DateTime<Utc>) -> Self

Set the time this metadata expires.

pub fn insert_metadata<D, M>( self, metadata: &SignedMetadata<D, M>, hash_algs: &[HashAlgorithm], ) -> Result<Self>
where M: Metadata, D: Pouf,

Add metadata to this snapshot metadata using the default path.

pub fn insert_metadata_with_path<P, D, M>( self, path: P, metadata: &SignedMetadata<D, M>, hash_algs: &[HashAlgorithm], ) -> Result<Self>
where P: Into<Cow<'static, str>>, M: Metadata, D: Pouf,

Add metadata to this snapshot metadata using a custom path.

pub fn insert_metadata_description( self, path: MetadataPath, description: MetadataDescription<TargetsMetadata>, ) -> Self

Add MetadataDescription to this snapshot metadata using a custom path.

pub fn build(self) -> Result<SnapshotMetadata>

Construct a new SnapshotMetadata.

pub fn signed<D>( self, private_key: &dyn PrivateKey, ) -> Result<SignedMetadata<D, SnapshotMetadata>>
where D: Pouf,

Construct a new SignedMetadata<D, SnapshotMetadata>.