State

Trait State 

pub trait State: Sealed { }
Trait to track each of the RepoBuilder building states.

This trait is sealed to make sure external users cannot implement the State crate with unexpected states.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<D: Pouf> State for Done<D>

Source

impl<D: Pouf> State for Timestamp<D>