pub struct EphemeralBatchUpdate<'a, D> { /* private fields */ }Expand description
EphemeralBatchUpdate is a special repository that is designed to write the metadata and targets to an EphemeralRepository in a single batch.
Note: EphemeralBatchUpdate::commit() must be called in order to write the metadata and
targets to the EphemeralRepository. Otherwise any queued changes will be lost on drop.
Implementations
Sourceimpl<D> EphemeralBatchUpdate<'_, D>where
D: Pouf,
impl<D> EphemeralBatchUpdate<'_, D>where
D: Pouf,
Sourcepub async fn commit(self) -> Result<(), CommitError>
pub async fn commit(self) -> Result<(), CommitError>
Write all the metadata and targets in the EphemeralBatchUpdate to the source EphemeralRepository in a single batch operation.