EphemeralRepository

Struct EphemeralRepository 

pub struct EphemeralRepository<D> { /* private fields */ }
An ephemeral repository contained solely in memory.

Implementations

Source

impl<D> EphemeralRepository<D>
where D: Pouf,

pub fn new() -> Self

Create a new ephemeral repository.

pub fn batch_update(&self) -> EphemeralBatchUpdate<'_, D>

Returns a EphemeralBatchUpdate for manipulating this repository. This allows callers to stage a number of mutations, and optionally atomically write them all at once.