FileSystemBatchUpdate

Struct FileSystemBatchUpdate 

pub struct FileSystemBatchUpdate<'a, D: Pouf> { /* private fields */ }
FileSystemBatchUpdate is a special repository that is designed to write the metadata and targets to an FileSystemRepository in a single batch.

Note: FileSystemBatchUpdate::commit() must be called in order to write the metadata and targets to the FileSystemRepository. Otherwise any queued changes will be lost on drop.

Implementations

Source

impl<D> FileSystemBatchUpdate<'_, D>
where D: Pouf,

pub async fn commit(self) -> Result<(), CommitError>

Write all the metadata and targets the FileSystemBatchUpdate to the source FileSystemRepository in a single batch operation.

Note: While this function will atomically write each file, it’s possible that this could fail with part of the files written if we experience a system error during the process.