HttpRepositoryBuilder

Struct HttpRepositoryBuilder 

pub struct HttpRepositoryBuilder<C, D>
where C: Connect + Sync + 'static, D: Pouf,
{ /* private fields */ }
A builder to create a repository accessible over HTTP.

Implementations

Source

impl<C, D> HttpRepositoryBuilder<C, D>
where C: Connect + Sync + 'static, D: Pouf,

pub fn new(url: Url, client: Client<C>) -> Self

Create a new repository with the given Url and Client.

pub fn new_with_uri(uri: Uri, client: Client<C>) -> Self

Create a new repository with the given Url and Client.

pub fn user_agent<T: Into<String>>(self, user_agent: T) -> Self

Set the User-Agent prefix.

Callers should include a custom User-Agent prefix to help maintainers of TUF repositories keep track of which client versions exist in the field.

pub fn metadata_prefix(self, metadata_prefix: Vec<String>) -> Self

The argument metadata_prefix is used to provide an alternate path where metadata is stored on the repository. If None, this defaults to /. For example, if there is a TUF repository at https://tuf.example.com/, but all metadata is stored at /meta/, then passing the arg Some("meta".into()) would cause root.json to be fetched from https://tuf.example.com/meta/root.json.

pub fn targets_prefix(self, targets_prefix: Vec<String>) -> Self

The argument targets_prefix is used to provide an alternate path where targets is stored on the repository. If None, this defaults to /. For example, if there is a TUF repository at https://tuf.example.com/, but all targets are stored at /targets/, then passing the arg Some("targets".into()) would cause hello-world to be fetched from https://tuf.example.com/targets/hello-world.

pub fn min_bytes_per_second(self, min: u32) -> Self

Set the minimum bytes per second for a read to be considered good.

pub fn build(self) -> HttpRepository<C, D>

Build a HttpRepository.