SnapshotMetadata

Struct SnapshotMetadata 

pub struct SnapshotMetadata { /* private fields */ }
Metadata for the snapshot role.

Implementations

Source

impl SnapshotMetadata

pub fn new( version: u32, expires: DateTime<Utc>, meta: HashMap<MetadataPath, MetadataDescription<TargetsMetadata>>, additional_fields: HashMap<String, Value>, ) -> Result<Self>

Create new SnapshotMetadata.

pub fn meta( &self, ) -> &HashMap<MetadataPath, MetadataDescription<TargetsMetadata>>

An immutable reference to the metadata paths and descriptions.

pub fn additional_fields(&self) -> &HashMap<String, Value>

An immutable reference to any additional fields on the metadata.