pub struct TargetPath(/* private fields */);Expand description
Wrapper for the virtual path to a target.
Implementations
Sourceimpl TargetPath
impl TargetPath
Sourcepub fn new<P: Into<String>>(path: P) -> Result<Self>
pub fn new<P: Into<String>>(path: P) -> Result<Self>
Create a new TargetPath from a String.
assert!(TargetPath::new("foo").is_ok());
assert!(TargetPath::new("/foo").is_err());
assert!(TargetPath::new("../foo").is_err());
assert!(TargetPath::new("foo/..").is_err());
assert!(TargetPath::new("foo/../bar").is_err());
assert!(TargetPath::new("..foo").is_ok());
assert!(TargetPath::new("foo/..bar").is_ok());
assert!(TargetPath::new("foo/bar..").is_ok());Sourcepub fn components(&self) -> Vec<String>
pub fn components(&self) -> Vec<String>
Split TargetPath into components that can be joined to create URL paths, Unix
paths, or Windows paths.
let path = TargetPath::new("foo/bar").unwrap();
assert_eq!(path.components(), ["foo".to_string(), "bar".to_string()]);Sourcepub fn is_child(&self, parent: &Self) -> bool
pub fn is_child(&self, parent: &Self) -> bool
Return whether this path is the child of another path.
let path1 = TargetPath::new("foo").unwrap();
let path2 = TargetPath::new("foo/bar").unwrap();
assert!(!path2.is_child(&path1));
let path1 = TargetPath::new("foo/").unwrap();
let path2 = TargetPath::new("foo/bar").unwrap();
assert!(path2.is_child(&path1));
let path2 = TargetPath::new("foo/bar/baz").unwrap();
assert!(path2.is_child(&path1));
let path2 = TargetPath::new("wat").unwrap();
assert!(!path2.is_child(&path1))Sourcepub fn matches_chain(&self, parents: &[HashSet<TargetPath>]) -> bool
pub fn matches_chain(&self, parents: &[HashSet<TargetPath>]) -> bool
Whether or not the current target is available at the end of the given chain of target paths. For the chain to be valid, each target path in a group must be a child of of all previous groups.
Sourcepub fn with_hash_prefix(&self, hash: &HashValue) -> Result<TargetPath>
pub fn with_hash_prefix(&self, hash: &HashValue) -> Result<TargetPath>
Prefix the target path with a hash value to support TUF spec 5.5.2.