pub trait State: Sealed { }Expand description
Trait to track each of the RepoBuilder building states.
This trait is sealed to make
sure external users cannot implement the State crate with unexpected states.
pub trait State: Sealed { }Trait to track each of the RepoBuilder building states.
This trait is sealed to make
sure external users cannot implement the State crate with unexpected states.