pub struct FileSystemRepository<D>where
D: Pouf,{ /* private fields */ }Expand description
A repository contained on the local file system.
Implementations
Sourceimpl<D> FileSystemRepository<D>where
D: Pouf,
impl<D> FileSystemRepository<D>where
D: Pouf,
Sourcepub fn builder<P: Into<PathBuf>>(
local_path: P,
) -> FileSystemRepositoryBuilder<D>
pub fn builder<P: Into<PathBuf>>( local_path: P, ) -> FileSystemRepositoryBuilder<D>
Create a FileSystemRepositoryBuilder.
Sourcepub fn new<P: Into<PathBuf>>(local_path: P) -> Self
pub fn new<P: Into<PathBuf>>(local_path: P) -> Self
Create a new repository on the local file system.
Sourcepub fn batch_update(&self) -> FileSystemBatchUpdate<'_, D>
pub fn batch_update(&self) -> FileSystemBatchUpdate<'_, D>
Returns a FileSystemBatchUpdate for manipulating this repository. This allows callers to stage a number of mutations, and optionally write them all at once.
FileSystemBatchUpdate will try to update any changed metadata or targets in a single transaction, and will fail if there are any conflict writes, either by directly calling FileSystemRepository::store_metadata, FileSystemRepository::store_target, or another FileSystemRepository::batch_update.
Warning: The current implementation makes no effort to prevent manipulations of the underlying filesystem, either in-process, or by an external process.